@@ -46,15 +46,23 @@ and provide a more dynamic mapping.
 import rpy2.robjects as robjects
 import rpy2.robjects.conversion as conversion
 import rpy2.rinterface as rinterface
-from rpy2.robjects.packages import importr
+from rpy2.robjects.packages import importr, WeakPackage
 import copy
 import warnings
 
 NULL = robjects.NULL
 
-ggplot2 = importr('ggplot2')
+ggplot2 = importr('ggplot2', on_conflict="warn")
+ggplot2 = WeakPackage(ggplot2._env,
+                      ggplot2.__rname__,
+                      translation=ggplot2._translation,
+                      exported_names=ggplot2._exported_names,
+                      on_conflict="warn",
+                      version=ggplot2.__version__,
+                      symbol_r2python=ggplot2._symbol_r2python,
+                      symbol_check_after=ggplot2._symbol_check_after)
 
-TARGET_VERSION = '2.0.0'
+TARGET_VERSION = '2.2.1'
 if ggplot2.__version__ != TARGET_VERSION:
    warnings.warn('This was designed againt ggplot2 version %s but you have %s' % (TARGET_VERSION, ggplot2.__version__))
 ggplot2_env = robjects.baseenv['as.environment']('package:ggplot2')
@@ -674,6 +682,12 @@ scale_fill_identity = ScaleFillIdentity.new
 class ScaleFillManual(ScaleFill):
     _constructor = ggplot2_env['scale_fill_manual']
 scale_fill_manual = ScaleFillManual.new
+class ScaleLinetypeContinuous(ScaleLinetype):
+    _constructor = ggplot2_env['scale_linetype_continuous']
+scale_linetype_continuous = ScaleLinetypeContinuous.new
+class ScaleLinetypeDiscrete(ScaleLinetype):
+    _constructor = ggplot2_env['scale_linetype_discrete']
+scale_linetype_discrete = ScaleLinetypeDiscrete.new
 class ScaleLinetypeManual(ScaleLinetype):
     _constructor = ggplot2_env['scale_linetype_manual']
 scale_linetype_manual = ScaleLinetypeManual.new
